Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5504)

Unified Diff: chrome/browser/ui/views/location_bar/translate_icon_view.h

Issue 25373009: Translate: New Bubble UX (for the view toolkit) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Add the browser test Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/location_bar/translate_icon_view.h
diff --git a/chrome/browser/ui/views/location_bar/star_view.h b/chrome/browser/ui/views/location_bar/translate_icon_view.h
similarity index 58%
copy from chrome/browser/ui/views/location_bar/star_view.h
copy to chrome/browser/ui/views/location_bar/translate_icon_view.h
index a2c7b95edbe9e4f4325f7c058237a83dd6e5d716..4b38e90760b3f235859a5b25161503136051b36f 100644
--- a/chrome/browser/ui/views/location_bar/star_view.h
+++ b/chrome/browser/ui/views/location_bar/translate_icon_view.h
@@ -1,21 +1,20 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_VIEWS_LOCATION_BAR_STAR_VIEW_H_
-#define CHROME_BROWSER_UI_VIEWS_LOCATION_BAR_STAR_VIEW_H_
+#ifndef CHROME_BROWSER_UI_VIEWS_LOCATION_BAR_TRANSLATE_ICON_VIEW_H_
+#define CHROME_BROWSER_UI_VIEWS_LOCATION_BAR_TRANSLATE_ICON_VIEW_H_
#include "ui/views/controls/image_view.h"
class CommandUpdater;
-class StarView : public views::ImageView {
+// The icon to show the Translate bubble where the user can have the page
+// tarnslated.
+class TranslateIconView : public views::ImageView {
public:
- explicit StarView(CommandUpdater* command_updater);
- virtual ~StarView();
-
- // Toggles the star on or off.
- void SetToggled(bool on);
+ explicit TranslateIconView(CommandUpdater* command_updater);
+ virtual ~TranslateIconView();
private:
// views::ImageView:
@@ -29,15 +28,14 @@ class StarView : public views::ImageView {
// ui::EventHandler:
virtual void OnGestureEvent(ui::GestureEvent* event) OVERRIDE;
- // The CommandUpdater for the Browser object that owns the location bar.
CommandUpdater* command_updater_;
// This is used to check if the bookmark bubble was showing during the mouse
// pressed event. If this is true then the mouse released event is ignored to
// prevent the bubble from reshowing.
bool suppress_mouse_released_action_;
- DISALLOW_COPY_AND_ASSIGN(StarView);
+ DISALLOW_COPY_AND_ASSIGN(TranslateIconView);
};
-#endif // CHROME_BROWSER_UI_VIEWS_LOCATION_BAR_STAR_VIEW_H_
+#endif // CHROME_BROWSER_UI_VIEWS_LOCATION_BAR_TRANSLATE_ICON_VIEW_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -29,15 +28,14 @@ class StarView : public views::ImageView {
CommandUpdater* command_updater_;
- // This is used to check if the bookmark bubble was showing during the mouse
+ // This is used to check if the translate bubble was showing during the mouse
// pressed event. If this is true then the mouse released event is ignored to
// prevent the bubble from reshowing.